@@ -1,5 +1,6 @@
 import argparse
 import logging
+import sys
 from typing import Type
 
 from .extractor import BaseExtractor, RunConfig
@@ -17,4 +18,5 @@ def cli_main(
     args = parser.parse_args()
 
     extractor = extractor_cls()
-    extractor.run(config=config_cls.from_json_file(args.config))
+    if not extractor.run(config=config_cls.from_json_file(args.config)):
+        sys.exit(1)
