@@ -36,7 +36,7 @@ class RunConfig:
 class BaseExtractor(ABC):
     """Base class for metadata extractors"""
 
-    def run(self, config: RunConfig) -> None:
+    def run(self, config: RunConfig) -> bool:
         """Callable function to extract metadata and send/post messages"""
         logger.info("Starting extractor {}".format(self.__class__.__name__))
 
@@ -44,13 +44,15 @@ class BaseExtractor(ABC):
 
         logger.info("Fetched {} entities".format(len(events)))
 
+        no_error = True
         if config.kinesis is not None:
-            Kinesis(config.kinesis).send_messages(events)
+            no_error = no_error & Kinesis(config.kinesis).send_messages(events)
 
         if config.api is not None:
-            IngestionApi(config.api).send_messages(events)
+            no_error = no_error & IngestionApi(config.api).send_messages(events)
 
         logger.info("Execution finished")
+        return no_error
 
     @abstractmethod
     async def extract(self, config: RunConfig) -> List[MetadataChangeEvent]:
