@@ -91,6 +91,7 @@ class AspectType(Enum):
     PERSON_PROPERTIES = "PERSON_PROPERTIES"
     PERSON_SLACK_PROFILE = "PERSON_SLACK_PROFILE"
     PROPERTIES = "PROPERTIES"
+    SUPPORT_INFO = "SUPPORT_INFO"
 
 
 class ChartType(Enum):
@@ -211,10 +212,10 @@ class DashboardPlatform(Enum):
 
 @dataclass
 class DashboardLogicalID:
-    """Identify an entity "logically", besides the system generated UUID.
+    """Identify an entity "logically".
     Each entity must have a logicalId to be ingested.
     A compelling use-case is that this allows a producer to create an
-    instance of the Entity without requiring a unique UUID to be
+    instance of the Entity without requiring an entity ID to be
     obtained prior to instantiation, potentially resulting in two round-trips
     """
     dashboard_id: Optional[str] = None
@@ -238,7 +239,6 @@ class DataPlatform(Enum):
     DOCUMENTDB = "DOCUMENTDB"
     DYNAMODB = "DYNAMODB"
     ELASTICSEARCH = "ELASTICSEARCH"
-    LOOKER = "LOOKER"
     MYSQL = "MYSQL"
     POSTGRESQL = "POSTGRESQL"
     RDS = "RDS"
@@ -251,10 +251,10 @@ class DataPlatform(Enum):
 
 @dataclass
 class DatasetLogicalID:
-    """Identify an entity "logically", besides the system generated UUID.
+    """Identify an entity "logically".
     Each entity must have a logicalId to be ingested.
     A compelling use-case is that this allows a producer to create an
-    instance of the Entity without requiring a unique UUID to be
+    instance of the Entity without requiring an entity ID to be
     obtained prior to instantiation, potentially resulting in two round-trips
     """
     name: Optional[str] = None
@@ -283,6 +283,7 @@ class DashboardUpstream:
     entity_id: Optional[str] = None
     dashboard_upstream_id: Optional[str] = None
     latest: Optional[bool] = None
+    source_datasets: Optional[List[str]] = None
     sources: Optional[List[DatasetLogicalID]] = None
 
     @staticmethod
@@ -294,8 +295,9 @@ class DashboardUpstream:
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         dashboard_upstream_id = from_union([from_str, from_none], obj.get("id"))
         latest = from_union([from_bool, from_none], obj.get("latest"))
+        source_datasets = from_union([lambda x: from_list(from_str, x), from_none], obj.get("sourceDatasets"))
         sources = from_union([lambda x: from_list(DatasetLogicalID.from_dict, x), from_none], obj.get("sources"))
-        return DashboardUpstream(id, aspect_type, created_at, entity_id, dashboard_upstream_id, latest, sources)
+        return DashboardUpstream(id, aspect_type, created_at, entity_id, dashboard_upstream_id, latest, source_datasets, sources)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -305,6 +307,7 @@ class DashboardUpstream:
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["id"] = from_union([from_str, from_none], self.dashboard_upstream_id)
         result["latest"] = from_union([from_bool, from_none], self.latest)
+        result["sourceDatasets"] = from_union([lambda x: from_list(from_str, x), from_none], self.source_datasets)
         result["sources"] = from_union([lambda x: from_list(lambda x: to_class(DatasetLogicalID, x), x), from_none], self.sources)
         return result
 
@@ -319,12 +322,15 @@ class Dashboard:
     dashboard_info: Optional[DashboardInfo] = None
     deleted_at: Optional[datetime] = None
     entity_type: Optional[EntityType] = None
+    """A getter for the id property that's directly generated from the
+    entity type & logical ID.
+    """
     dashboard_id: Optional[str] = None
     last_modified_at: Optional[datetime] = None
-    """Identify an entity "logically", besides the system generated UUID.
+    """Identify an entity "logically".
     Each entity must have a logicalId to be ingested.
     A compelling use-case is that this allows a producer to create an
-    instance of the Entity without requiring a unique UUID to be
+    instance of the Entity without requiring an entity ID to be
     obtained prior to instantiation, potentially resulting in two round-trips
     """
     logical_id: Optional[DashboardLogicalID] = None
@@ -491,6 +497,9 @@ class DatasetDownstream:
     id: Optional[ObjectID] = None
     aspect_type: Optional[AspectType] = None
     created_at: Optional[datetime] = None
+    dashboards: Optional[List[DashboardLogicalID]] = None
+    dependent_dashboards: Optional[List[str]] = None
+    dependent_datasets: Optional[List[str]] = None
     destinations: Optional[List[DatasetLogicalID]] = None
     entity_id: Optional[str] = None
     dataset_downstream_id: Optional[str] = None
@@ -502,17 +511,23 @@ class DatasetDownstream:
         id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
         aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
         created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        dashboards = from_union([lambda x: from_list(DashboardLogicalID.from_dict, x), from_none], obj.get("dashboards"))
+        dependent_dashboards = from_union([lambda x: from_list(from_str, x), from_none], obj.get("dependentDashboards"))
+        dependent_datasets = from_union([lambda x: from_list(from_str, x), from_none], obj.get("dependentDatasets"))
         destinations = from_union([lambda x: from_list(DatasetLogicalID.from_dict, x), from_none], obj.get("destinations"))
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         dataset_downstream_id = from_union([from_str, from_none], obj.get("id"))
         latest = from_union([from_bool, from_none], obj.get("latest"))
-        return DatasetDownstream(id, aspect_type, created_at, destinations, entity_id, dataset_downstream_id, latest)
+        return DatasetDownstream(id, aspect_type, created_at, dashboards, dependent_dashboards, dependent_datasets, destinations, entity_id, dataset_downstream_id, latest)
 
     def to_dict(self) -> dict:
         result: dict = {}
         result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
         result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
         result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["dashboards"] = from_union([lambda x: from_list(lambda x: to_class(DashboardLogicalID, x), x), from_none], self.dashboards)
+        result["dependentDashboards"] = from_union([lambda x: from_list(from_str, x), from_none], self.dependent_dashboards)
+        result["dependentDatasets"] = from_union([lambda x: from_list(from_str, x), from_none], self.dependent_datasets)
         result["destinations"] = from_union([lambda x: from_list(lambda x: to_class(DatasetLogicalID, x), x), from_none], self.destinations)
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["id"] = from_union([from_str, from_none], self.dataset_downstream_id)
@@ -522,10 +537,10 @@ class DatasetDownstream:
 
 @dataclass
 class GroupID:
-    """Identify an entity "logically", besides the system generated UUID.
+    """Identify an entity "logically".
     Each entity must have a logicalId to be ingested.
     A compelling use-case is that this allows a producer to create an
-    instance of the Entity without requiring a unique UUID to be
+    instance of the Entity without requiring an entity ID to be
     obtained prior to instantiation, potentially resulting in two round-trips
     """
     group_name: Optional[str] = None
@@ -563,10 +578,10 @@ class GroupOwner:
 
 @dataclass
 class PersonID:
-    """Identify an entity "logically", besides the system generated UUID.
+    """Identify an entity "logically".
     Each entity must have a logicalId to be ingested.
     A compelling use-case is that this allows a producer to create an
-    instance of the Entity without requiring a unique UUID to be
+    instance of the Entity without requiring an entity ID to be
     obtained prior to instantiation, potentially resulting in two round-trips
     """
     email: Optional[str] = None
@@ -875,6 +890,74 @@ class DatasetStatistics:
         return result
 
 
+@dataclass
+class ChannelSlackInfo:
+    channel_id: Optional[str] = None
+    is_archived: Optional[bool] = None
+    name: Optional[str] = None
+    purpose: Optional[str] = None
+    team_id: Optional[str] = None
+    topic: Optional[str] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'ChannelSlackInfo':
+        assert isinstance(obj, dict)
+        channel_id = from_union([from_str, from_none], obj.get("channelId"))
+        is_archived = from_union([from_bool, from_none], obj.get("isArchived"))
+        name = from_union([from_str, from_none], obj.get("name"))
+        purpose = from_union([from_str, from_none], obj.get("purpose"))
+        team_id = from_union([from_str, from_none], obj.get("teamId"))
+        topic = from_union([from_str, from_none], obj.get("topic"))
+        return ChannelSlackInfo(channel_id, is_archived, name, purpose, team_id, topic)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["channelId"] = from_union([from_str, from_none], self.channel_id)
+        result["isArchived"] = from_union([from_bool, from_none], self.is_archived)
+        result["name"] = from_union([from_str, from_none], self.name)
+        result["purpose"] = from_union([from_str, from_none], self.purpose)
+        result["teamId"] = from_union([from_str, from_none], self.team_id)
+        result["topic"] = from_union([from_str, from_none], self.topic)
+        return result
+
+
+@dataclass
+class SupportInfo:
+    id: Optional[ObjectID] = None
+    aspect_type: Optional[AspectType] = None
+    created_at: Optional[datetime] = None
+    email: Optional[str] = None
+    entity_id: Optional[str] = None
+    support_info_id: Optional[str] = None
+    latest: Optional[bool] = None
+    slack_info: Optional[ChannelSlackInfo] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'SupportInfo':
+        assert isinstance(obj, dict)
+        id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
+        aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
+        created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        email = from_union([from_str, from_none], obj.get("email"))
+        entity_id = from_union([from_str, from_none], obj.get("entityId"))
+        support_info_id = from_union([from_str, from_none], obj.get("id"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
+        slack_info = from_union([ChannelSlackInfo.from_dict, from_none], obj.get("slackInfo"))
+        return SupportInfo(id, aspect_type, created_at, email, entity_id, support_info_id, latest, slack_info)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
+        result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
+        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["email"] = from_union([from_str, from_none], self.email)
+        result["entityId"] = from_union([from_str, from_none], self.entity_id)
+        result["id"] = from_union([from_str, from_none], self.support_info_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
+        result["slackInfo"] = from_union([lambda x: to_class(ChannelSlackInfo, x), from_none], self.slack_info)
+        return result
+
+
 @dataclass
 class DatasetField:
     dataset: Optional[DatasetLogicalID] = None
@@ -928,6 +1011,7 @@ class DatasetUpstream:
     dataset_upstream_id: Optional[str] = None
     latest: Optional[bool] = None
     source_code_url: Optional[str] = None
+    source_datasets: Optional[List[str]] = None
     sources: Optional[List[DatasetLogicalID]] = None
     transformation: Optional[str] = None
 
@@ -943,9 +1027,10 @@ class DatasetUpstream:
         dataset_upstream_id = from_union([from_str, from_none], obj.get("id"))
         latest = from_union([from_bool, from_none], obj.get("latest"))
         source_code_url = from_union([from_str, from_none], obj.get("sourceCodeUrl"))
+        source_datasets = from_union([lambda x: from_list(from_str, x), from_none], obj.get("sourceDatasets"))
         sources = from_union([lambda x: from_list(DatasetLogicalID.from_dict, x), from_none], obj.get("sources"))
         transformation = from_union([from_str, from_none], obj.get("transformation"))
-        return DatasetUpstream(id, aspect_type, created_at, entity_id, executor_url, field_mappings, dataset_upstream_id, latest, source_code_url, sources, transformation)
+        return DatasetUpstream(id, aspect_type, created_at, entity_id, executor_url, field_mappings, dataset_upstream_id, latest, source_code_url, source_datasets, sources, transformation)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -958,6 +1043,7 @@ class DatasetUpstream:
         result["id"] = from_union([from_str, from_none], self.dataset_upstream_id)
         result["latest"] = from_union([from_bool, from_none], self.latest)
         result["sourceCodeUrl"] = from_union([from_str, from_none], self.source_code_url)
+        result["sourceDatasets"] = from_union([lambda x: from_list(from_str, x), from_none], self.source_datasets)
         result["sources"] = from_union([lambda x: from_list(lambda x: to_class(DatasetLogicalID, x), x), from_none], self.sources)
         result["transformation"] = from_union([from_str, from_none], self.transformation)
         return result
@@ -976,12 +1062,15 @@ class Dataset:
     """DatasetDownstream captures downstream lineages from this dataset"""
     downstream: Optional[DatasetDownstream] = None
     entity_type: Optional[EntityType] = None
+    """A getter for the id property that's directly generated from the
+    entity type & logical ID.
+    """
     dataset_id: Optional[str] = None
     last_modified_at: Optional[datetime] = None
-    """Identify an entity "logically", besides the system generated UUID.
+    """Identify an entity "logically".
     Each entity must have a logicalId to be ingested.
     A compelling use-case is that this allows a producer to create an
-    instance of the Entity without requiring a unique UUID to be
+    instance of the Entity without requiring an entity ID to be
     obtained prior to instantiation, potentially resulting in two round-trips
     """
     logical_id: Optional[DatasetLogicalID] = None
@@ -992,6 +1081,7 @@ class Dataset:
     records or the last refresh time.
     """
     statistics: Optional[DatasetStatistics] = None
+    support_info: Optional[SupportInfo] = None
     """DatasetUpstream captures upstream lineages from data sources to this dataset"""
     upstream: Optional[DatasetUpstream] = None
 
@@ -1013,8 +1103,9 @@ class Dataset:
         properties = from_union([Properties.from_dict, from_none], obj.get("properties"))
         schema = from_union([DatasetSchema.from_dict, from_none], obj.get("schema"))
         statistics = from_union([DatasetStatistics.from_dict, from_none], obj.get("statistics"))
+        support_info = from_union([SupportInfo.from_dict, from_none], obj.get("supportInfo"))
         upstream = from_union([DatasetUpstream.from_dict, from_none], obj.get("upstream"))
-        return Dataset(created_at, id, comments, dataset_created_at, deleted_at, documentation, downstream, entity_type, dataset_id, last_modified_at, logical_id, ownership, properties, schema, statistics, upstream)
+        return Dataset(created_at, id, comments, dataset_created_at, deleted_at, documentation, downstream, entity_type, dataset_id, last_modified_at, logical_id, ownership, properties, schema, statistics, support_info, upstream)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -1033,6 +1124,7 @@ class Dataset:
         result["properties"] = from_union([lambda x: to_class(Properties, x), from_none], self.properties)
         result["schema"] = from_union([lambda x: to_class(DatasetSchema, x), from_none], self.schema)
         result["statistics"] = from_union([lambda x: to_class(DatasetStatistics, x), from_none], self.statistics)
+        result["supportInfo"] = from_union([lambda x: to_class(SupportInfo, x), from_none], self.support_info)
         result["upstream"] = from_union([lambda x: to_class(DatasetUpstream, x), from_none], self.upstream)
         return result
 
@@ -1112,12 +1204,15 @@ class Group:
     deleted_at: Optional[datetime] = None
     entity_type: Optional[EntityType] = None
     group_info: Optional[GroupInfo] = None
+    """A getter for the id property that's directly generated from the
+    entity type & logical ID.
+    """
     group_id: Optional[str] = None
     last_modified_at: Optional[datetime] = None
-    """Identify an entity "logically", besides the system generated UUID.
+    """Identify an entity "logically".
     Each entity must have a logicalId to be ingested.
     A compelling use-case is that this allows a producer to create an
-    instance of the Entity without requiring a unique UUID to be
+    instance of the Entity without requiring an entity ID to be
     obtained prior to instantiation, potentially resulting in two round-trips
     """
     logical_id: Optional[GroupID] = None
@@ -1392,13 +1487,16 @@ class Person:
     editable_info: Optional[PersonEditableInfo] = None
     entity_type: Optional[EntityType] = None
     first_name: Optional[str] = None
+    """A getter for the id property that's directly generated from the
+    entity type & logical ID.
+    """
     person_id: Optional[str] = None
     last_modified_at: Optional[datetime] = None
     last_name: Optional[str] = None
-    """Identify an entity "logically", besides the system generated UUID.
+    """Identify an entity "logically".
     Each entity must have a logicalId to be ingested.
     A compelling use-case is that this allows a producer to create an
-    instance of the Entity without requiring a unique UUID to be
+    instance of the Entity without requiring an entity ID to be
     obtained prior to instantiation, potentially resulting in two round-trips
     """
     logical_id: Optional[PersonID] = None
