@@ -7,6 +7,7 @@ from typing import Dict, List, Optional
 
 from dataclasses_json import dataclass_json
 
+from metaphor.common.entity_id import EntityId
 from metaphor.common.event_util import EventUtil
 from metaphor.common.extractor import BaseExtractor, RunConfig
 from metaphor.common.metadata_change_event import (
@@ -134,11 +135,14 @@ class DbtExtractor(BaseExtractor):
             dataset.upstream = DatasetUpstream()
             dataset.upstream.aspect_type = AspectType.DATASET_UPSTREAM
             dataset.upstream.source_code_url = model["original_file_path"]
-            dataset.upstream.sources = [
+            dataset.upstream.source_datasets = [
                 self._get_upstream(n, platform, datasets)
                 for n in model["depends_on"]["nodes"]
             ]
 
+            # TODO: Remove once the deprecated field is dropped
+            dataset.upstream.sources = []
+
     def _parse_test(self, test: Dict) -> None:
         test_meta = test["test_metadata"]
         model_arg = test_meta["kwargs"]["model"]
@@ -292,10 +296,8 @@ class DbtExtractor(BaseExtractor):
         return doc
 
     @staticmethod
-    def _get_upstream(
-        node: str, platform: str, datasets: Dict[str, Dict]
-    ) -> DatasetLogicalID:
+    def _get_upstream(node: str, platform: str, datasets: Dict[str, Dict]) -> str:
         dataset_id = DatasetLogicalID()
         dataset_id.platform = DataPlatform[platform]
         dataset_id.name = DbtExtractor._get_dataset_name(datasets[node])
-        return dataset_id
+        return str(EntityId(EntityType.DATASET, dataset_id))
