@@ -87,7 +87,7 @@ class PostgresqlExtractor(BaseExtractor):
     @staticmethod
     def _dataset_name(db: str, schema: str, table: str) -> str:
         """The full table name including database, schema and name"""
-        return f"{db}.{schema}.{table}"
+        return f"{db}.{schema}.{table}".lower()
 
     @staticmethod
     async def _connect_database(config: PostgresqlRunConfig, database: str):
